function response = hACQSetChannelDelay(instrument, channel, delayNanoSeconds)
%function response = hACQSetChannelDelay(instrument, channel, delayNanoSeconds)
%Sets the channel delay for a given channel, in units of nanoseconds.  This
%is used to compensate for the distance to the sensor.  This applies only
%to the full spectrum acquisition.
%
%parameters:
%instrument - The tcp-ip object that is connected to the Hyperion Instrument.
%channel - The channel on which the delay is to be set.
%delayNanoSeconds - Integer number of nanoseconds corresponding to the
%expected round-trip time of flight for the sensor channel.
%return value:
%response - A response structure (see hCOMMReadResponse)
argument = sprintf('%d %d', channel, delayNanoSeconds);

response = hCOMMExecuteCommand(instrument, '#SetChannelDelay', argument, 0, 10);